from setuptools import setup, find_packages

setup(
    name='whatimiss',
    version='0.0.1',
    author='zhangmin',
    author_email='a991391009@gmail.com',
    description='打包示例',
    url='https://github.com/zhangminvip',
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)